@@ -466,17 +466,17 @@ class CommunityClient(AminoHttpClient):
         }
 
         if blogId:
-            response = await self.post(f"/g/s/blog/{blogId}/tipping", data)
+            response = await self.post(f"/x{self.comId}/s/blog/{blogId}/tipping", data)
             return response.status
         
         elif chatId:
-            response = await self.post(f"/g/s/chat/thread/{chatId}/tipping", data)
+            response = await self.post(f"/x{self.comId}/s/chat/thread/{chatId}/tipping", data)
             return response.status
         
         elif objectId:
             data["objectId"] = objectId
             data["objectType"] = ObjectTypes.ITEM
-            response = await self.post(f"/g/s/tipping", data)
+            response = await self.post(f"/x{self.comId}/s/tipping", data)
             return response.status
         
         else: SpecifyType() 
@@ -877,12 +877,12 @@ class CommunityClient(AminoHttpClient):
         response = await self.get(f"/x{self.comId}/s/chat/thread/{chatId}")
         return Thread(loads(await response.json())["thread"])
 
-    async def get_chat_messages(self, chatId: str, size: int = 25, pageToken: str = None) -> Message:
+    async def get_chat_messages(self, chatId: str, size: int = 25, pageToken: str = None) -> List[Message]:
         if not pageToken: params = f"v=2&pagingType=t&size={size}"
         else: params = f"v=2&pagingType=t&pageToken={pageToken}&size={size}"
 
         response = await self.get(f"/x{self.comId}/s/chat/thread/{chatId}/message?{params}")
-        return list(map(lambda o, p: Message(**o, **p), (data := await response.json())["messageList"], data["paging"]))
+        return list(map(lambda o: Message(**o, **data["paging"]), (data := await response.json())["messageList"]))
 
     async def get_message_info(self, chatId: str, messageId: str) -> Message:
         response = await self.get(f"/x{self.comId}/s/chat/thread/{chatId}/message/{messageId}")
@@ -940,7 +940,7 @@ class CommunityClient(AminoHttpClient):
         else: params = f"v=2&pagingType=t&pageToken={pageToken}&start={start}&size={size}"
         
         response = await self.get(f"/x{self.comId}/s/feed/blog-all?{params}")
-        return list(map(lambda o, p: Blog(**o, **p), (data := await response.json())["blogList"], data["paging"]))
+        return list(map(lambda o: Blog(**o, **data["paging"]), (data := await response.json())["blogList"]))
 
     async def get_chat_users(self, chatId: str, start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/x{self.comId}/s/chat/thread/{chatId}/member?start={start}&size={size}&type=default&cv=1.2")
@@ -1454,20 +1454,20 @@ class CommunityClient(AminoHttpClient):
     
     async def get_chat_bubble(self, bubbleId: str) -> ChatBubble:
         response = await self.get(f"/x{self.comId}/s/chat/chat-bubble/{bubbleId}")
-        return ChatBubble(**(response.text)["chatBubble"])
+        return ChatBubble(**(await response.json())["chatBubble"])
 
     async def get_chat_bubble_templates(self, start: int = 0, size: int = 25) -> List[ChatBubble]:
         response = await self.get(f"/x{self.comId}/s/chat/chat-bubble/templates?start={start}&size={size}")
         return list(map(lambda o: ChatBubble(**o), (await response.json())["templateList"]))
     
-    async def generate_chat_bubble(self, bubble: BinaryIO = None, 
+    async def generate_chat_bubble(self, bubble: bytes = None, 
             templateId: str = "949156e1-cc43-49f0-b9cf-3bbbb606ad6e") -> ChatBubble:
-        response = await self.post(f"/x{self.comId}/s/chat/chat-bubble/templates/{templateId}/generate", bubble)
-        return ChatBubble(**(response.text)["chatBubble"])
+        response = await self.post(f"/x{self.comId}/s/chat/chat-bubble/templates/{templateId}/generate", data=bubble, type=FileTypes.STREAM)
+        return ChatBubble(**(await response.json())["chatBubble"])
     
-    async def edit_chat_bubble(self, bubbleId: str, bubble: BinaryIO) -> ChatBubble:
-        response = await self.post(f"/x{self.comId}/s/chat/chat-bubble/{bubbleId}", bubble)
-        return ChatBubble(**(response.text)["chatBubble"])
+    async def edit_chat_bubble(self, bubbleId: str, bubble: bytes) -> ChatBubble:
+        response = await self.post(f"/x{self.comId}/s/chat/chat-bubble/{bubbleId}", data=bubble, type=FileTypes.STREAM)
+        return ChatBubble(**(await response.json())["chatBubble"])
 
     async def send_active_object(self, timers: List[dict], timezone: int = 0, flags: int = 0):
         data = {
