@@ -2,7 +2,7 @@ import base64
 import locale
 import io
 
-from typing import BinaryIO, List, Union
+from typing import BinaryIO, List, Tuple, Union
 from uuid import uuid4
 from zipfile import ZIP_DEFLATED, ZipFile
 from aiohttp import ClientSession, ClientTimeout
@@ -35,7 +35,7 @@ class Client(AminoHttpClient):
         self.proxy: Optional[str] = proxy
         self.proxy_auth: Optional[str] = proxy_auth
         self.authenticated: bool = False
-        self.deviceId: str = deviceId or generate_device_sync()
+        self.deviceId: str = deviceId or self.deviceId
 
         self.auth: Auth = Auth(**{})
         self.account: Account = Account(**{})
@@ -82,7 +82,7 @@ class Client(AminoHttpClient):
         return callback
     
     async def initialize_community(self, comId: str = None, aminoId: str = None, 
-            get_info: bool = True, community: Community = None) -> CommunityClient:
+            get_info: bool = False, community: Community = None) -> CommunityClient:
         if aminoId:
             comId = (await self.search_community(aminoId))[0].comId
 
@@ -91,7 +91,7 @@ class Client(AminoHttpClient):
         
         if not aminoId and not comId: raise NoCommunity()
 
-        return CommunityClient(comId, self._loop, self._session,
+        return CommunityClient(comId, self._loop, None,
                 community, self.headers, self.proxy, self.proxy_auth)
     
     def run(self, email: str = None, password: str = None, sid: str = None) -> Auth:
@@ -112,6 +112,7 @@ class Client(AminoHttpClient):
 
     async def login(self, email: str, password: str) -> Auth:
         data = {
+            "v": 2,
             "email": email,
             "clientType": 100,
             "secret": f"0 {password}",
@@ -304,12 +305,12 @@ class Client(AminoHttpClient):
         response = await self.post(f"/g/s/device", data)
         return response.status
     
-    async def upload_media(self, file: BinaryIO, fileType: str) -> str:
-        response = await self.post_content(f"/g/s/media/upload", file.read(), fileType)
+    async def upload_media(self, image: bytes, fileType: str = FileTypes.IMAGE) -> str:
+        response = await self.post(f"/g/s/media/upload", None, image, fileType)
         return (await response.json())["mediaValue"]
     
-    async def upload_bubble_preview(self, file: BinaryIO) -> str:
-        response = await self.post_content(f"{self.api}/g/s/media/upload/target/chat-bubble-thumbnail", file.read(), "image/png")
+    async def upload_bubble_thumbnail(self, image: bytes) -> str:
+        response = await self.post(f"{self.api}/g/s/media/upload/target/chat-bubble-thumbnail", None, image, "image/png")
         return (await response.json())["mediaValue"]
     
     async def get_eventlog(self, language: str = "en") -> dict:
@@ -928,7 +929,7 @@ class Client(AminoHttpClient):
 
     async def get_link_info(self, code: str) -> Link:
         response = await self.get(f"/g/s/link-resolution?q={code}")
-        return Link(**(ext := (await response.json())["linkInfoV2"]["extensions"]), **ext["linkInfo"])
+        return Link(**(ext := (await response.json())["linkInfoV2"]["extensions"]), **ext.get("linkInfo", {}))
     
     async def get_from_id(self, objectId: str, objectType: int, comId: str = None) -> Link:
         data = {
@@ -1029,25 +1030,25 @@ class Client(AminoHttpClient):
         }
         return ChatBubble.Config(**bubbleConfig)
 
-    async def generate_bubble_file(self, bubbleImage: BinaryIO = None, bubbleConfig: ChatBubble.Config = None) -> BinaryIO:
+    async def generate_bubble_file(self, bubbleImage: bytes = None, bubbleConfig: ChatBubble.Config = None) -> bytes:
         if bubbleImage is None:
             response = await self.get("http://cb1.narvii.com/images/6846/eebb8b22237e1b80f46de62284abd0c74cb440f9_00.png")
-            bubbleImage = io.BytesIO(await response.read())
+            bubbleImage = await response.read()
 
         if not bubbleConfig:
             bubbleConfig = self.create_bubble_config()
 
         buffer = io.BytesIO()
         with ZipFile(buffer, 'w', ZIP_DEFLATED) as zipfile:
-            zipfile.writestr(bubbleConfig.backgroundPath, bubbleImage.read())
+            zipfile.writestr(bubbleConfig.backgroundPath, bubbleImage)
             zipfile.writestr("config.json", bubbleConfig.json())
-        return buffer
+        return buffer.getvalue()
 
-    def load_bubble(self, bubble_zip: BinaryIO) -> tuple[bytes, ChatBubble]:
-        with ZipFile(bubble_zip, 'r') as zipfile:
+    def load_bubble(self, bubble_zip: BinaryIO) -> Tuple[bytes, ChatBubble.Config]:
+        with ZipFile(io.BytesIO(bubble_zip), 'r') as zipfile:
             config = loads(zipfile.read("config.json"))
 
-            config = ChatBubble.Config(config)
+            config = ChatBubble.Config(**config)
             background = zipfile.read(config.backgroundPath)
         return background, config
 
