@@ -3,8 +3,6 @@ from asyncio.events import AbstractEventLoop, get_event_loop
 
 from contextlib import suppress
 from time import time
-from typing import Optional
-from aiohttp import ClientWebSocketResponse
 from aiohttp.client import ClientSession
 from aiohttp.client_exceptions import WSServerHandshakeError
 from aiohttp.client_ws import ClientWebSocketResponse as WSConnection
@@ -45,8 +43,8 @@ class WebSocketClient:
 
                 if recieved_data["t"] == 1000:
                     self.emitter.emit("message", Event(**recieved_data["o"]))
-                else:
-                    self.emitter.emit("event", recieved_data["o"])
+                
+                self.emitter.emit("event", recieved_data["o"])
                 
 
     async def create_connection(self) -> WSConnection:
@@ -59,7 +57,7 @@ class WebSocketClient:
                 headers = {
                     "NDCDEVICEID": self.auth.deviceId,
                     "NDCAUTH": f"sid={self.auth.sid}",
-                    "NDC-MSG-SIG": await generate_signature(data)
+                    "NDC-MSG-SIG": generate_signature(data)
                 }
 
                 return await self._session.ws_connect(url, headers=headers)
